@@ -118,7 +118,7 @@ class AlthermaUnitController:
             if not valid:
                 #raise AlthermaException(
                 #    f'Invalid argument {value} for operation {operation} or operation is not settable.')
-                logger.warning("Invalid argument {value} for operation {operation} or operation is not settable.")
+                logger.warning(f"Invalid argument {value} for operation {operation} or operation is not settable.")
             payload = {
                 'con': value,
                 'cnf': 'text/plain:0'
